@@ -12,7 +12,6 @@ class SecretManager:
         self.__region_name = region_name
 
     def get_secrets_manager_client(self):
-        print('INFO: In secrets_manager_client')
         try:
             session = boto3.session.Session(aws_access_key_id=self.__access_key,
                                             aws_secret_access_key=self.__secret_key)
@@ -22,8 +21,9 @@ class SecretManager:
             raise e
 
     # Retrieves the secret value for the given secret name from AWS Secrets Manager.
-    def get_secret_key_value(self, secret_name):
-        print(f"INFO: In get_secret_key_value for: {secret_name}")
+    def get_secret_key_value(self, secret_name, verbose=False):
+        if verbose:
+            print(f"INFO: In get_secret_key_value for: {secret_name}")
         client = self.get_secrets_manager_client()
         try:
             get_secret_key_value_response = client.get_secret_value(SecretId=secret_name)
